searchData={"items":[{"type":"module","title":"FuzzyCompare","doc":"This module compares two strings for their similarity and uses multiple\napproaches to get high quality results.","ref":"FuzzyCompare.html"},{"type":"module","title":"Getting started - FuzzyCompare","doc":"In order to compare two strings with each other do the following:\n\n    iex> FuzzyCompare.similarity(\"Oscar-Claude Monet\", \"monet, claude\")\n    0.95","ref":"FuzzyCompare.html#module-getting-started"},{"type":"module","title":"Inner workings - FuzzyCompare","doc":"Imagine you had to [match some names](https://en.wikipedia.org/wiki/Record_linkage).\n\nTry to match the following list of painters:\n\n  * `\"Oscar-Claude Monet\"`\n  * `\"Edouard Manet\"`\n  * `\"Monet, Claude\"`\n\nFor a human it is easy to see that some of the names have just been flipped\nand that others are different but similar sounding.\n\nA first approrach could be to compare the strings with a string similarity\nfunction like the\n[Jaro-Winkler](https://en.wikipedia.org/wiki/Jaro%E2%80%93Winkler_distance)\nfunction.\n\n    iex> String.jaro_distance(\"Oscar-Claude Monet\", \"Monet, Claude\")\n    0.5407763532763533\n\n    iex> String.jaro_distance(\"Oscar-Claude Monet\", \"Edouard Manet\")\n    0.624928774928775\n\nThis is not an improvement over exact equality.\n\nIn order to improve the results this library uses two different approaches,\n`FuzzyCompare.ChunkSet` and `FuzzyCompare.SortedChunks`.","ref":"FuzzyCompare.html#module-inner-workings"},{"type":"module","title":"Sorted chunks - FuzzyCompare","doc":"This approach yields good results when words within a string have been\nshuffled around. The strategy will sort all substrings by words and compare\nthe sorted strings.\n\n    iex> FuzzyCompare.SortedChunks.substring_similarity(\"Oscar-Claude Monet\", \"Monet, Claude\")\n    1.0\n\n    iex(4)> FuzzyCompare.SortedChunks.substring_similarity(\"Oscar-Claude Monet\", \"Edouard Manet\")\n    0.6944444444444443","ref":"FuzzyCompare.html#module-sorted-chunks"},{"type":"module","title":"Chunkset - FuzzyCompare","doc":"The chunkset approach is best in scenarios when the strings contain other\nsubstrings that are not relevant to what is being searched for.\n\n    iex> FuzzyCompare.ChunkSet.standard_similarity(\"Claude Monet\", \"Alice Hoschedé was the wife of Claude Monet\")\n    1.0","ref":"FuzzyCompare.html#module-chunkset"},{"type":"module","title":"Substring comparison - FuzzyCompare","doc":"Should one of the strings be much longer than the other the library will\nattempt to compare matching substrings only.","ref":"FuzzyCompare.html#module-substring-comparison"},{"type":"module","title":"Credits - FuzzyCompare","doc":"This library is inspired by a [seatgeek blogpost from 2011](https://chairnerd.seatgeek.com/fuzzywuzzy-fuzzy-string-matching-in-python/).","ref":"FuzzyCompare.html#module-credits"},{"type":"function","title":"FuzzyCompare.similarity/2","doc":"Compares two binaries for their similarity and returns a float in the range of\n`0.0` and `1.0` where `0.0` means no similarity and `1.0` means exactly alike.","ref":"FuzzyCompare.html#similarity/2"},{"type":"function","title":"Examples - FuzzyCompare.similarity/2","doc":"iex> FuzzyCompare.similarity(\"Oscar-Claude Monet\", \"monet, claude\")\n    0.95\n\n    iex> String.jaro_distance(\"Oscar-Claude Monet\", \"monet, claude\")\n    0.5407763532763533","ref":"FuzzyCompare.html#similarity/2-examples"},{"type":"function","title":"Preprocessing - FuzzyCompare.similarity/2","doc":"The ratio function expects either strings or the `FuzzyCompare.Preprocessed` struct.\n\nWhen comparing a large list of strings against always the same string it is\nadvisable to run the preprocessing once and pass the `FuzzyCompare.Preprocessed` struct.\nThat way you pay for preprocessing of the constant string only once.","ref":"FuzzyCompare.html#similarity/2-preprocessing"},{"type":"module","title":"FuzzyCompare.ChunkSet","doc":"For strings which among shared words also contain many dissimilar words the\nChunkSet is ideal.\n\nIt works in the following way:\n\nOur input strings are\n\n  * `\"oscar claude monet\"`\n  * `\"alice hoschedé was the wife of claude monet\"`\n\nFrom the input string three strings are created.\n  * `common_words = \"claude monet\"`\n  * `common_words_plus_remaining_words_left = \"claude monet oscar\"`\n  * `common_words_plus_remaining_words_right = \"claude monet alice hoschedé was the wife of\"`\n\nThese are then all compared with each other in pairs and the maximum ratio\nis returned.","ref":"FuzzyCompare.ChunkSet.html"},{"type":"module","title":"Examples - FuzzyCompare.ChunkSet","doc":"iex> FuzzyCompare.ChunkSet.standard_similarity(\"oscar claude monet\", \"alice hoschedé was the wife of claude monet\")\n    0.8958333333333334\n\n    iex> FuzzyCompare.ChunkSet.substring_similarity(\"oscar claude monet\", \"alice hoschedé was the wife of claude monet\")\n    1.0","ref":"FuzzyCompare.ChunkSet.html#module-examples"},{"type":"function","title":"FuzzyCompare.ChunkSet.standard_similarity/2","doc":"","ref":"FuzzyCompare.ChunkSet.html#standard_similarity/2"},{"type":"function","title":"FuzzyCompare.ChunkSet.substring_similarity/2","doc":"","ref":"FuzzyCompare.ChunkSet.html#substring_similarity/2"},{"type":"module","title":"FuzzyCompare.Preprocessed","doc":"Struct to hold the processed string","ref":"FuzzyCompare.Preprocessed.html"},{"type":"module","title":"FuzzyCompare.Preprocessor","doc":"This module allows for the preprocessing of strings which will be used in the\ncomparision. Preprocessing is vital for high quality results. During\nprocessing the input strings are upcased, all punctuation is stripped,\nexcess whitespace is trimmed and a Map of values is returned which is used\nby all other comparison functions. This allows for the reuse of preprocessed\nvalues and prevents each comparison function from rerunning the preprocessing.","ref":"FuzzyCompare.Preprocessor.html"},{"type":"function","title":"FuzzyCompare.Preprocessor.process/1","doc":"","ref":"FuzzyCompare.Preprocessor.html#process/1"},{"type":"function","title":"FuzzyCompare.Preprocessor.process/2","doc":"","ref":"FuzzyCompare.Preprocessor.html#process/2"},{"type":"module","title":"FuzzyCompare.SortedChunks","doc":"In order to match strings whose order might be the only thing separating them\nthe sorted chunks metric is applied. This strategy splits the strings on spaces,\nsorts the list of strings, joins them together again, and then compares them\nby applying the Jaro-Winkler distance metric.","ref":"FuzzyCompare.SortedChunks.html"},{"type":"module","title":"Examples - FuzzyCompare.SortedChunks","doc":"iex> FuzzyCompare.SortedChunks.standard_similarity(\"Oscar-Claude Monet\", \"Monet, Claude\")\n    0.8958333333333334\n\n    iex> FuzzyCompare.SortedChunks.substring_similarity(\"Oscar-Claude Monet\", \"Monet, Claude\")\n    1.0","ref":"FuzzyCompare.SortedChunks.html#module-examples"},{"type":"function","title":"FuzzyCompare.SortedChunks.standard_similarity/2","doc":"","ref":"FuzzyCompare.SortedChunks.html#standard_similarity/2"},{"type":"function","title":"FuzzyCompare.SortedChunks.substring_similarity/2","doc":"","ref":"FuzzyCompare.SortedChunks.html#substring_similarity/2"},{"type":"module","title":"FuzzyCompare.StandardStringComparison","doc":"This module just wraps the `String.jaro_distance/2` function but it allows\nus to use a different comparison function in the future should the need ever\narise.","ref":"FuzzyCompare.StandardStringComparison.html"},{"type":"function","title":"FuzzyCompare.StandardStringComparison.similarity/2","doc":"","ref":"FuzzyCompare.StandardStringComparison.html#similarity/2"},{"type":"module","title":"FuzzyCompare.Strategy","doc":"This module is used to determine whether all comparison functions should use\nthe simple ratio function or the substring ratio function.","ref":"FuzzyCompare.Strategy.html"},{"type":"function","title":"FuzzyCompare.Strategy.determine_strategy/2","doc":"","ref":"FuzzyCompare.Strategy.html#determine_strategy/2"},{"type":"module","title":"FuzzyCompare.SubstringComparison","doc":"This module offers the functionality of comparing strings of different\nlengths.\n\n    iex> FuzzyCompare.SubstringComparison.similarity(\"DEUTSCHLAND\", \"BUNDESREPUBLIK DEUTSCHLAND\")\n    0.9090909090909092\n\n    iex> String.jaro_distance(\"DEUTSCHLAND\", \"BUNDESREPUBLIK DEUTSCHLAND\")\n    0.5399600399600399","ref":"FuzzyCompare.SubstringComparison.html"},{"type":"function","title":"FuzzyCompare.SubstringComparison.similarity/2","doc":"The ratio function takes two strings as arguments and returns the substring\nsimilarity of those strings as a float between 0 and 1.\n\nThe substring matching works by generating a list of equal substrings by means of\n[Myers Difference](http://citeseerx.ist.psu.edu/viewdoc/summary?doi=10.1.1.4.6927),\ncomparing these substrings with the Jaro-Winkler function against the shorter\none of the two input strings and finally returning the maximum comparison\nvalue found.\n\nLet us assume as the input string the following: `\"DEUTSCHLAND\"` and\n`\"BUNDESREPUBLIK DEUTSCHLAND\"`. This yields the the matching substrings of\n`[\"DE\", \"U\", \"TSCHLAND\"]`.\n\nWe compare each one of them to the shorter one of the input strings:\n\n    iex> String.jaro_distance(\"DE\", \"DEUTSCHLAND\")\n    0.7272727272727272\n\n    iex> String.jaro_distance(\"U\", \"DEUTSCHLAND\")\n    0.6969696969696969\n\n    iex> String.jaro_distance(\"TSCHLAND\", \"DEUTSCHLAND\")\n    0.9090909090909092\n\nOf all comparisons the highest value gets returned.","ref":"FuzzyCompare.SubstringComparison.html#similarity/2"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}